pub struct HttpError {
    pub message: String,
    pub status_code: StatusCode,
}
The error type contains a status code and a string message.

It implements [IntoResponse], so can be used in axum handler.

Example

fn handler() -> Result<impl IntoResponse, HttpError> {
    Ok(())
}

Often it can to more convenient to use HttpResult

Example

fn handler() -> HttpResult<impl IntoResponse> {
    Ok(())
}

Fields

message: Stringstatus_code: StatusCode